summaryrefslogtreecommitdiffstats
path: root/korn/subjectsdlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'korn/subjectsdlg.h')
-rw-r--r--korn/subjectsdlg.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/korn/subjectsdlg.h b/korn/subjectsdlg.h
index 8201e8e6..e7c8a985 100644
--- a/korn/subjectsdlg.h
+++ b/korn/subjectsdlg.h
@@ -36,11 +36,11 @@ class KornSubjectsDlg: public KDialogBase
public:
/**
* SubjectListViewItem Constructor
* @param tqparent list view
* @param item KornMailSubject this item should represent. It is NOT deleted
* if SubjectListViewItem is deleted.
*/
- SubjectListViewItem( TQListView *tqparent, KornMailSubject * item);
+ SubjectListViewItem( TQListView *parent, KornMailSubject * item);
/**
* SubjectListViewItem Destructor
@@ -104,9 +104,9 @@ class KornSubjectsDlg: public KDialogBase
public:
/**
* KornSubjectsDlg Constructor
* @param tqparent tqparent widget
*/
- KornSubjectsDlg( TQWidget *tqparent=0 );
+ KornSubjectsDlg( TQWidget *parent=0 );
/**
* This functions clears all available KMailDrop's.
@@ -36,11 +36,11 @@ class KornSubjectsDlg: public KDialogBase
/**
* SubjectListViewItem Constructor
- * @param tqparent list view
+ * @param parent list view
* @param item KornMailSubject this item should represent. It is NOT deleted
* if SubjectListViewItem is deleted.
@@ -104,9 +104,9 @@ class KornSubjectsDlg: public KDialogBase
/**
* KornSubjectsDlg Constructor
- * @param tqparent tqparent widget
+ * @param parent parent widget
*/